@@ -162,7 +162,8 @@ AP4_AvcFrameParser::AP4_AvcFrameParser() :
     m_PrevFrameNum(0),
     m_PrevFrameNumOffset(0),
     m_PrevPicOrderCntMsb(0),
-    m_PrevPicOrderCntLsb(0)
+    m_PrevPicOrderCntLsb(0),
+    m_keepParameterSets(true)
 {
     for (unsigned int i=0; i<256; i++) {
         m_PPS[i] = NULL;
@@ -1209,6 +1210,7 @@ AP4_AvcFrameParser::Feed(const AP4_UI08* nal_unit,
                                       nal_ref_idc,
                                       *slice_header);
             if (AP4_FAILED(result)) {
+                delete slice_header;
                 return AP4_ERROR_INVALID_FORMAT;
             }
             
