@@ -664,6 +664,57 @@ AP4_HevcProfileTierLevel::Parse(AP4_BitReader& bits, unsigned int max_num_sub_la
     return AP4_SUCCESS;
 }
 
+/*----------------------------------------------------------------------
+|   AP4_HevcVuiParameters::AP4_HevcVuiParameters
++---------------------------------------------------------------------*/
+AP4_HevcVuiParameters::AP4_HevcVuiParameters() :
+    aspect_ratio_info_present_flag(0),
+    aspect_ratio_idc(0),
+    sar_width(0),
+    sar_height(0),
+    overscan_info_present_flag(0),
+    overscan_appropriate_flag(0),
+    video_signal_type_present_flag(0),
+    video_format(0),
+    video_full_range_flag(0),
+    colour_description_present_flag(0),
+    colour_primaries(0),
+    transfer_characteristics(0),
+    matrix_coeffs(0)
+{
+}
+
+/*----------------------------------------------------------------------
+|   AP4_HevcVuiParameters::Parse
++---------------------------------------------------------------------*/
+AP4_Result
+AP4_HevcVuiParameters::Parse(AP4_BitReader& bits, unsigned int& transfer_characteristics)
+{
+    // vui_parameters
+    aspect_ratio_info_present_flag = bits.ReadBit();
+    if (aspect_ratio_info_present_flag) {
+        aspect_ratio_idc = bits.ReadBits(8);
+        if (aspect_ratio_idc == 255) {
+            sar_width  = bits.ReadBits(16);
+            sar_height = bits.ReadBits(16);
+        }
+    }
+    overscan_info_present_flag = bits.ReadBit();
+    if (overscan_info_present_flag) overscan_appropriate_flag = bits.ReadBit();
+    video_signal_type_present_flag = bits.ReadBit();
+    if (video_signal_type_present_flag) {
+        video_format                    = bits.ReadBits(3);
+        video_full_range_flag           = bits.ReadBit();
+        colour_description_present_flag = bits.ReadBit();
+        if (colour_description_present_flag) {
+            colour_primaries         = bits.ReadBits(8);
+            transfer_characteristics = bits.ReadBits(8);
+            matrix_coeffs            = bits.ReadBits(8);
+        }
+    }
+    return AP4_SUCCESS;
+}
+
 /*----------------------------------------------------------------------
 |   AP4_HevcPictureParameterSet::AP4_HevcPictureParameterSet
 +---------------------------------------------------------------------*/
@@ -827,9 +878,11 @@ AP4_HevcSequenceParameterSet::AP4_HevcSequenceParameterSet() :
     long_term_ref_pics_present_flag(0),
     num_long_term_ref_pics_sps(0),
     sps_temporal_mvp_enabled_flag(0),
-    strong_intra_smoothing_enabled_flag(0)
+    strong_intra_smoothing_enabled_flag(0),
+    vui_parameters_present_flag(0)
 {
     AP4_SetMemory(&profile_tier_level, 0, sizeof(profile_tier_level));
+    AP4_SetMemory(&vui_parameters, 0, sizeof(vui_parameters));
     for (unsigned int i=0; i<8; i++) {
         sps_max_dec_pic_buffering_minus1[i] = 0;
         sps_max_num_reorder_pics[i]         = 0;
@@ -935,6 +988,13 @@ AP4_HevcSequenceParameterSet::Parse(const unsigned char* data, unsigned int data
     }
     sps_temporal_mvp_enabled_flag  = bits.ReadBit();
     strong_intra_smoothing_enabled_flag = bits.ReadBit();
+    vui_parameters_present_flag = bits.ReadBit();
+    if (vui_parameters_present_flag) {
+      AP4_Result result = vui_parameters.Parse(bits, vui_parameters.transfer_characteristics);
+      if (AP4_FAILED(result)) {
+        return result;
+      }
+    }
 
     return AP4_SUCCESS;
 }
@@ -1045,7 +1105,8 @@ AP4_HevcFrameParser::AP4_HevcFrameParser() :
     m_AccessUnitFlags(0),
     m_VclNalUnitsInAccessUnit(0),
     m_PrevTid0Pic_PicOrderCntMsb(0),
-    m_PrevTid0Pic_PicOrderCntLsb(0)
+    m_PrevTid0Pic_PicOrderCntLsb(0),
+    m_keepParameterSets(true)
 {
     for (unsigned int i=0; i<=AP4_HEVC_PPS_MAX_ID; i++) {
         m_PPS[i] = NULL;
