@@ -142,8 +142,7 @@ AP4_IsmaCipher::GetDecryptedSampleSize(AP4_Sample& sample)
 |   AP4_IsmaCipher::DecryptSampleData
 +---------------------------------------------------------------------*/
 AP4_Result 
-AP4_IsmaCipher::DecryptSampleData(AP4_UI32 poolid,
-                                  AP4_DataBuffer& data_in,
+AP4_IsmaCipher::DecryptSampleData(AP4_DataBuffer& data_in,
                                   AP4_DataBuffer& data_out,
                                   const AP4_UI08* /*iv*/)
 {
@@ -334,7 +333,7 @@ AP4_Result
 AP4_IsmaTrackDecrypter::ProcessSample(AP4_DataBuffer& data_in,
                                       AP4_DataBuffer& data_out)
 {
-    return m_Cipher->DecryptSampleData(0, data_in, data_out);
+    return m_Cipher->DecryptSampleData(data_in, data_out);
 }
 
 /*----------------------------------------------------------------------
